import { createSlice } from "@reduxjs/toolkit";
import { useSelector } from "react-redux";
import { UpdateUser } from "../api/user";

const User = createSlice({
  name: "user",
  initialState: {
    codeHash: "",
    isLoggedIn: false,
    user: {},
  },
  reducers: {
    login: (state, action) => {
      let { user } = action.payload;
      if (user) {
        UpdateUser(user)
          .then((d) => {
            console.debug("update user success: %o", d);
          })
          .catch((e) => {
            console.error("update user failed: %o", e);
          });
        state.isLoggedIn = true;
        state.user = action.payload;
      }
    },
    logout: (state) => {
      state.isLoggedIn = false;
      state.user = {};
    },
    setCodeHash: (state, action) => {
      state.codeHash = action.payload;
    },
  },
});

export function useSelectorUser() {
  return useSelector((state: any) => state.user.user);
}

export function useSelectorIsLoggedIn() {
  return useSelector((state: any) => state.user.isLoggedIn);
}

export function useSelectCodeHash() {
  return useSelector((state: any) => state.user.codeHash);
}

export const { login, logout, setCodeHash } = User.actions;

export default User.reducer;
